---
title: <span class="badge object-type-scalar"></span> Farad
---
# <span class="badge object-type-scalar"></span> Farad

Energy: Farad (F)

## Definition

```python
# Energy: Farad (F)
Farad: typing.Literal["farad"] = "farad"
```
